@@ -2,19 +2,20 @@
  * The IKE Scanner (ike-scan) is Copyright (C) 2003-2009 Roy Hills,
  * NTA Monitor Ltd.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- * 
- * This program is distributed in the hope that it will be useful,
+ * This file is part of ike-scan.
+ *
+ * ike-scan is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * ike-scan is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * along with ike-scan.  If not, see <http://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -30,10 +31,8 @@
  * If this license is unacceptable to you, I may be willing to negotiate
  * alternative licenses (contact ike-scan@nta-monitor.com).
  *
- * You are encouraged to send comments, improvements or suggestions to
- * me at ike-scan@nta-monitor.com.
- *
- * $Id$
+ * You are encouraged to submit comments, improvements or suggestions
+ * at the github repository https://github.com/royhills/ike-scan
  *
  * ike-scan.h -- Header file for IKE Scanner (ike-scan)
  *
@@ -200,6 +199,7 @@
 #define OPT_NAT_T 267
 #define OPT_RCOOKIE 268
 #define OPT_READPKTFROMFILE 269
+#define OPT_BINDIP 270
 #undef DEBUG_TIMINGS			/* Define to 1 to debug timing code */
 /* #define WRITE_RECEIVED_IKE_PACKET "received-ike-packet.dat" */
 
@@ -219,7 +219,7 @@ typedef struct {
 
 typedef struct {
    time_list *recv_times; 	/* List of receive times */
-   misc_data *extra;		/* Extra data for this entry */ 
+   misc_data *extra;		/* Extra data for this entry */
    unsigned n;			/* Ordinal number for this entry */
    unsigned timeout;		/* Timeout for this host */
    uint32_t icookie[COOKIE_SIZE];	/* IKE Initiator cookie */
@@ -392,7 +392,7 @@ unsigned char* make_attr(size_t *, int, unsigned, size_t, unsigned, void *);
 unsigned char* add_attr(int, size_t *, int, unsigned, size_t, unsigned,
                         void *);
 unsigned char* make_vid(size_t *, unsigned, unsigned char *, size_t);
-unsigned char* add_vid(int, size_t *, unsigned char *, size_t, unsigned);
+unsigned char* add_vid(int, size_t *, unsigned char *, size_t, int, unsigned);
 unsigned char* make_ke(size_t *, unsigned, size_t);
 unsigned char* make_ke2(size_t *, unsigned, unsigned, size_t);
 unsigned char* make_nonce(size_t *, unsigned, size_t);
@@ -459,10 +459,5 @@ double genrand_real1(void);
 double genrand_real2(void);
 double genrand_real3(void);
 double genrand_res53(void);
-/* The following functions are just to prevent rcsid being optimised away */
-void error_use_rcsid(void);
-void isakmp_use_rcsid(void);
-void wrappers_use_rcsid(void);
-void utils_use_rcsid(void);
 
 #endif	/* IKE_SCAN_H */
