@@ -1,20 +1,21 @@
 /*
- * The IKE Scanner (ike-scan) is Copyright (C) 2003-2007 Roy Hills,
+ * The IKE Scanner (ike-scan) is Copyright (C) 2003-2013 Roy Hills,
  * NTA Monitor Ltd.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * This file is part of ike-scan.
  *
- * This program is distributed in the hope that it will be useful,
+ * ike-scan is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * ike-scan is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * along with ike-scan.  If not, see <http://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -30,10 +31,8 @@
  * If this license is unacceptable to you, I may be willing to negotiate
  * alternative licenses (contact ike-scan@nta-monitor.com).
  *
- * You are encouraged to send comments, improvements or suggestions to
- * me at ike-scan@nta-monitor.com.
- *
- * $Id$
+ * You are encouraged to submit comments, improvements or suggestions
+ * at the github repository https://github.com/royhills/ike-scan
  *
  * Author: Roy Hills
  * Date: 7 November 2003
@@ -44,8 +43,6 @@
 
 #include "ike-scan.h"
 
-static char rcsid[] = "$Id$";	/* RCS ID for ident(1) */
-
 const id_name_map notification_map[] = { /* From RFC 2408 3.14.1 */
    {0, "UNSPECIFIED"},
    {1, "INVALID-PAYLOAD-TYPE"},
@@ -85,7 +82,7 @@ const id_name_map notification_map[] = { /* From RFC 2408 3.14.1 */
    {24578, "INITIAL-CONTACT"},
    {-1, NULL}
 };
-const id_name_map notification_map2[] = { /* From RFC 4306 3.10.1 */
+const id_name_map notification_map2[] = { /* From RFC 5996 3.10.1 */
    {0, "RESERVED"},
    {1, "UNSUPPORTED_CRITICAL_PAYLOAD"},
    {4, "INVALID_IKE_SPI"},
@@ -102,6 +99,8 @@ const id_name_map notification_map2[] = { /* From RFC 4306 3.10.1 */
    {37, "FAILED_CP_REQUIRED"},
    {38, "TS_UNACCEPTABLE"},
    {39, "INVALID_SELECTORS"},
+   {43, "TEMPORARY_FAILURE"},
+   {44, "CHILD_SA_NOT_FOUND"},
    {9101, "Checkpoint-Firewall-1"},
    {9110, "Checkpoint-Firewall-1"},
    {16384, "INITIAL_CONTACT"},
@@ -138,7 +137,7 @@ const id_name_map attr_map[] = {	/* From RFC 2409 App. A and */
    {16384, "GSSIdentityName"},
    {-1, NULL}
 };
-const id_name_map trans_type_map[] = {	/* From RFC 4306 3.3.2 */
+const id_name_map trans_type_map[] = {	/* From RFC 5996 3.3.2 */
    {1, "Encr"},
    {2, "Prf"},
    {3, "Integ"},
@@ -154,7 +153,7 @@ const id_name_map enc_map[] = {	/* From RFC 2409 App. A */
    {5, "3DES"},
    {6, "CAST"},
    {7, "AES"},		/* RFC 3602 */
-   {8, "Camellia"},	/* draft-kato-ipsec-ciph-camellia-01.txt */
+   {8, "Camellia"},	/* RFC 4312 */
    {65001, "Mars"},	/* Defined in strongSwan constants.h */
    {65002, "RC6"},	/* Defined in strongSwan constants.h */
    {65003, "ID_65003"},	/* Defined in strongSwan constants.h */
@@ -162,7 +161,7 @@ const id_name_map enc_map[] = {	/* From RFC 2409 App. A */
    {65005, "Twofish"},	/* Defined in strongSwan constants.h */
    {-1, NULL}
 };
-const id_name_map encr_map[] = {	/* From RFC 4306 3.3.2 */
+const id_name_map encr_map[] = {	/* From RFC 5996 (IKEv2) 3.3.2 */
    {1, "DES_IV64"},
    {2, "DES"},
    {3, "3DES"},
@@ -175,6 +174,13 @@ const id_name_map encr_map[] = {	/* From RFC 4306 3.3.2 */
    {11, "NULL"},
    {12, "AES_CBC"},
    {13, "AES_CTR"},
+   {14, "AES_CCM_ICV8"},		/* RFC 5282 */
+   {15, "AES_CCM_ICV12"},		/* RFC 5282 */
+   {16, "AES_CCM_ICV16"},		/* RFC 5282 */
+   {18, "AES_GCM_ICV8"},		/* RFC 5282 */
+   {19, "AES_GCM_ICV12"},		/* RFC 5282 */
+   {20, "AES_GCM_ICV16"},		/* RFC 5282 */
+   {23, "CAMELLIA_CBC"},		/* RFC 5996 */
    {-1, NULL}
 };
 const id_name_map hash_map[] = {	/* From RFC 2409 App. A */
@@ -186,11 +192,15 @@ const id_name_map hash_map[] = {	/* From RFC 2409 App. A */
    {6, "SHA2-512"},
    {-1, NULL}
 };
-const id_name_map prf_map[] = {		/* From RFC 4306 3.3.2 */
+const id_name_map prf_map[] = {		/* From RFC 5996 3.3.2 */
    {1, "HMAC_MD5"},
    {2, "HMAC_SHA1"},
    {3, "HMAC_TIGER"},
-   {4, "AES128_XCBC"},
+   {4, "AES128_XCBC"},		/* RFC 4434 */
+   {5, "HMAC_SHA2_256"},	/* RFC 4868 */
+   {6, "HMAC_SHA2_384"},	/* RFC 4868 */
+   {7, "HMAC_SHA2_512"},	/* RFC 4868 */
+   {8, "HMAC_AES128_CMAC"},	/* RFC 4615 */
    {-1, NULL}
 };
 const id_name_map auth_map[] = {	/* From RFC 2409 App. A */
@@ -202,29 +212,42 @@ const id_name_map auth_map[] = {	/* From RFC 2409 App. A */
    {6, "ElGamel_Enc"},
    {7, "ElGamel_RevEnc"},
    {8, "ECDSA_Sig"},
-   {128, "CRACK"},	/* From draft-harkins-ipsra-crack-00 */
-   {64221, "Hybrid"},
-   {65001, "XAUTH_PSK"},
-   {65003, "XAUTH_DSS"},
-   {65005, "XAUTH_RSA"},
-   {65007, "XAUTH_RSA_Enc"},
-   {65009, "XAUTH_RSA_RevEnc"},
+   {9, "ECDSA_SHA256"},		/* RFC 4754 */
+   {10, "ECDSA_SHA384"},	/* RFC 4754 */
+   {11, "ECDSA_SHA512"},	/* RFC 4754 */
+   {128, "CRACK"},		/* draft-harkins-ipsra-crack-00 */
+   {64221, "Hybrid_RSA"},	/* draft-ietf-ipsec-isakmp-hybrid-auth-05 */
+   {64223, "Hybrid_DSS"},	/* draft-ietf-ipsec-isakmp-hybrid-auth-05 */
+   {65001, "XAUTH_PSK"},	/* draft-ietf-ipsec-isakmp-xauth-06 */
+   {65003, "XAUTH_DSS"},	/* draft-ietf-ipsec-isakmp-xauth-06 */
+   {65005, "XAUTH_RSA"},	/* draft-ietf-ipsec-isakmp-xauth-06 */
+   {65007, "XAUTH_RSA_Enc"},	/* draft-ietf-ipsec-isakmp-xauth-06 */
+   {65009, "XAUTH_RSA_RevEnc"},	/* draft-ietf-ipsec-isakmp-xauth-06 */
    {-1, NULL}
 };
-const id_name_map integ_map[] = {	/* From RFC 4306 3.3.2 */
+const id_name_map integ_map[] = {	/* From RFC 5996 3.3.2 */
    {1, "HMAC_MD5_96"},
    {2, "HMAC_SHA1_96"},
    {3, "DES_MAC"},
    {4, "KPDK_MD5"},
    {5, "AES_XCBC_96"},
+   {6, "HMAC_MD5_128"},		/* RFC 4595 */
+   {7, "HMAC_SHA1_160"},	/* RFC 4595 */
+   {8, "AES_CMAC_96"},		/* RFC 4494 */
+   {9, "AES_128_GMAC"},		/* RFC 4543 */
+   {10, "AES_192_GMAC"},	/* RFC 4543 */
+   {11, "AES_256_GMAC"},	/* RFC 4543 */
+   {12, "HMAC_SHA2_256_128"},	/* RFC 4868 */
+   {13, "HMAC_SHA2_384_192"},	/* RFC 4868 */
+   {14, "HMAC_SHA2_512_256"},	/* RFC 4868 */
    {-1, NULL}
 };
 const id_name_map dh_map[] = {	/* From RFC 2409 App. A */
-   {1, "1:modp768"},			/* and RFC 3526 */
+   {1, "1:modp768"},
    {2, "2:modp1024"},
    {3, "3:ec2n155"},
    {4, "4:ec2n185"},
-   {5, "5:modp1536"},
+   {5, "5:modp1536"},	/* RFC 3526 */
    {6, "6:ec2n163"},
    {7, "7:ec2n163"},
    {8, "8:ec2n283"},
@@ -233,11 +256,23 @@ const id_name_map dh_map[] = {	/* From RFC 2409 App. A */
    {11, "11:ec2n409"},
    {12, "12:ec2n571"},
    {13, "13:ec2n571"},
-   {14, "14:modp2048"},
-   {15, "15:modp3072"},
-   {16, "16:modp4096"},
-   {17, "17:modp6144"},
-   {18, "18:modp8192"},
+   {14, "14:modp2048"},	/* RFC 3526 */
+   {15, "15:modp3072"},	/* RFC 3526 */
+   {16, "16:modp4096"},	/* RFC 3526 */
+   {17, "17:modp6144"},	/* RFC 3526 */
+   {18, "18:modp8192"},	/* RFC 3526 */
+   {19, "19:ecp256"},	/* RFC 5903 */
+   {20, "20:ecp384"},	/* RFC 5903 */
+   {21, "21:ecp521"},	/* RFC 5903 */
+   {22, "22:modp1024s160"},	/* RFC 5114 */
+   {23, "23:modp2048s224"},	/* RFC 5114 */
+   {24, "24:modp2048s256"},	/* RFC 5114 */
+   {25, "25:ecp192"},	/* RFC 5114 */
+   {26, "26:ecp224"},	/* RFC 5114 */
+   {27, "27:brainpoolP224r1"},	/* RFC 6954 */
+   {28, "28:brainpoolP256r1"},	/* RFC 6954 */
+   {29, "29:brainpoolP384r1"},	/* RFC 6954 */
+   {30, "30:brainpoolP512r1"},	/* RFC 6954 */
    {-1, NULL}
 };
 const id_name_map life_map[] = {	/* From RFC 2409 App. A */
@@ -260,7 +295,7 @@ const id_name_map payload_map[] = {	/* Payload types from RFC 2408 3.1 */
    {12, "Delete"},
    {13, "VendorID"},
    {20, "NAT-D"},		/* RFC 3947 NAT Discovery */
-   {33, "SecurityAssociation"},
+   {33, "SecurityAssociation"},	/* Values 33-48 are from RFC 5996 IKEv2 */
    {34, "KeyExchange"},
    {35, "IDI"},
    {36, "IDR"},
@@ -276,11 +311,13 @@ const id_name_map payload_map[] = {	/* Payload types from RFC 2408 3.1 */
    {46, "Encrypted"},
    {47, "Configuration"},
    {48, "EAP"},
+   {49, "GSPM"},		/* RFC 6467 */
    {-1, NULL}
 };
 const id_name_map doi_map[] = {
    {0, "ISAKMP"},
    {1, "IPsec"},
+   {2, "GDOI"},		/* RFC 6407 */
    {-1, NULL}
 };
 const id_name_map protocol_map[] = {
@@ -905,7 +942,7 @@ add_transform(int finished, size_t *length, unsigned trans_id,
  *	Pointer to transform payload.
  *
  *	This constructs a single IKEv2 transform payload.
- *	Most of the values are defined in RFC 4306 Section 3.3.
+ *	Most of the values are defined in RFC 5996 Section 3.3.
  */
 unsigned char*
 make_transform2(size_t *length, unsigned next, unsigned trans_type,
@@ -976,7 +1013,7 @@ add_transform2(int finished, size_t *length, unsigned trans_type,
    size_t len;					/* Transform length */
 /*
  * Construct a transform if we are not finalising.
- * Set next to ISAKMP_NEXT_T (more transforms) 
+ * Set next to ISAKMP_NEXT_T (more transforms)
  */
    if (!finished) {
       trans = make_transform2(&len, ISAKMP_NEXT_T, trans_type, trans_id, attr,
@@ -1162,6 +1199,7 @@ make_vid(size_t *length, unsigned next, unsigned char *vid_data,
  *      length  (output) length of entire VID payload set.
  *      vid_data        Vendor ID data
  *      vid_data_len    Vendor ID data length
+ *	ike_version	IKE version
  *	next		Next payload type (only when finished == 1)
  *
  *	Returns:
@@ -1177,7 +1215,7 @@ make_vid(size_t *length, unsigned next, unsigned char *vid_data,
  */
 unsigned char*
 add_vid(int finished, size_t *length, unsigned char *vid_data,
-        size_t vid_data_len, unsigned next) {
+        size_t vid_data_len, int ike_version, unsigned next) {
    static int first_vid = 1;
    static unsigned char *vid_start=NULL;	/* Start of set of VIDs */
    static size_t cur_offset;			/* Start of current VID */
@@ -1188,7 +1226,11 @@ add_vid(int finished, size_t *length, unsigned char *vid_data,
  * Construct a VID if we are not finalising.
  */
    if (!finished) {
-      vid = make_vid(&len, ISAKMP_NEXT_VID, vid_data, vid_data_len);
+      if (ike_version == 1) {
+         vid = make_vid(&len, ISAKMP_NEXT_VID, vid_data, vid_data_len);
+      } else {
+         vid = make_vid(&len, ISAKMP_NEXT_V2_VID, vid_data, vid_data_len);
+      }
       if (first_vid) {
          cur_offset = 0;
          end_offset = len;
@@ -2678,6 +2720,10 @@ print_psk_crack_values(const char *psk_crack_file) {
    hexdata=hexstring(psk_values.hash_r, psk_values.hash_r_len);
    fprintf(fp, "%s\n", hexdata);
    free(hexdata);
+
+   if (psk_crack_file[0]) {
+      fclose(fp);
+   }
 }
 
 /*
@@ -2732,8 +2778,3 @@ clone_payload(const unsigned char *pkt_ptr, size_t bytes_left) {
 
    return clone_ptr;
 }
-
-void
-isakmp_use_rcsid(void) {
-   fprintf(stderr, "%s\n", rcsid);	/* Use rcsid to stop compiler optimising away */
-}
