@@ -2,19 +2,20 @@
  * The IKE Scanner (ike-scan) is Copyright (C) 2003-2007 Roy Hills,
  * NTA Monitor Ltd.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- * 
- * This program is distributed in the hope that it will be useful,
+ * This file is part of ike-scan.
+ *
+ * ike-scan is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * ike-scan is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * along with ike-scan.  If not, see <http://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -30,10 +31,8 @@
  * If this license is unacceptable to you, I may be willing to negotiate
  * alternative licenses (contact ike-scan@nta-monitor.com).
  *
- * You are encouraged to send comments, improvements or suggestions to
- * me at ike-scan@nta-monitor.com.
- *
- * $Id$
+ * You are encouraged to submit comments, improvements or suggestions
+ * at the github repository https://github.com/royhills/ike-scan
  *
  * psk-crack.c -- IKE Aggressive Mode Pre-Shared Key cracker for ike-scan
  *
@@ -47,8 +46,6 @@
 #include "psk-crack.h"
 #include "hash_functions.h"
 
-static const char rcsid[] = "$Id$";	/* RCS ID for ident(1) */
-
 static const char *default_charset =
    "0123456789abcdefghijklmnopqrstuvwxyz"; /* default bruteforce charset */
 
@@ -106,11 +103,6 @@ main (int argc, char *argv[]) {
             fprintf(stderr, "General Public License.\n");
             fprintf(stderr, "For more information about these matters, see the file named COPYING.\n");
             fprintf(stderr, "\n");
-/* We use rcsid here to prevent it being optimised away */
-            fprintf(stderr, "%s\n", rcsid);
-            error_use_rcsid();
-            utils_use_rcsid();
-            wrappers_use_rcsid();
             exit(EXIT_SUCCESS);
             break;	/* NOTREACHED */
          case 'B':      /* --bruteforce */
@@ -632,7 +624,7 @@ psk_crack_usage(int status) {
    fprintf(stderr, "\n--charset=<s> or -c <s>\tSet bruteforce character set to <s>\n");
    fprintf(stderr, "\t\t\tDefault is \"%s\"\n", default_charset);
    fprintf(stderr, "\n");
-   fprintf(stderr, "Report bugs or send suggestions to %s\n", PACKAGE_BUGREPORT);
+   fprintf(stderr, "Report bugs or send suggestions at %s\n", PACKAGE_BUGREPORT);
    fprintf(stderr, "See the ike-scan homepage at http://www.nta-monitor.com/tools/ike-scan/\n");
    exit(status);
 }
