@@ -2,19 +2,20 @@
  * The IKE Scanner (ike-scan) is Copyright (C) 2003-2007 Roy Hills,
  * NTA Monitor Ltd.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- * 
- * This program is distributed in the hope that it will be useful,
+ * This file is part of ike-scan.
+ *
+ * ike-scan is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * ike-scan is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * along with ike-scan.  If not, see <http://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -30,10 +31,8 @@
  * If this license is unacceptable to you, I may be willing to negotiate
  * alternative licenses (contact ike-scan@nta-monitor.com).
  *
- * You are encouraged to send comments, improvements or suggestions to
- * me at ike-scan@nta-monitor.com.
- *
- * $Id$
+ * You are encouraged to submit comments, improvements or suggestions
+ * at the github repository https://github.com/royhills/ike-scan
  *
  * psk-crack.h -- Header file for psk-crack
  *
@@ -163,9 +162,5 @@ char *make_message(const char *, ...);
 char *numstr(unsigned);
 char *printable(const unsigned char*, size_t);
 char *hexstring(const unsigned char*, size_t);
-/* The following functions are just to prevent rcsid being optimised away */
-void error_use_rcsid(void);
-void wrappers_use_rcsid(void);
-void utils_use_rcsid(void);
 
 #endif	/* PSK_CRACK_H */
