@@ -2,19 +2,20 @@
  * The IKE Scanner (ike-scan) is Copyright (C) 2003-2009 Roy Hills,
  * NTA Monitor Ltd.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * This file is part of ike-scan.
  *
- * This program is distributed in the hope that it will be useful,
+ * ike-scan is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * ike-scan is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * along with ike-scan.  If not, see <http://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -30,10 +31,8 @@
  * If this license is unacceptable to you, I may be willing to negotiate
  * alternative licenses (contact ike-scan@nta-monitor.com).
  *
- * You are encouraged to send comments, improvements or suggestions to
- * me at ike-scan@nta-monitor.com.
- *
- * $Id$
+ * You are encouraged to submit comments, improvements or suggestions
+ * at the github repository https://github.com/royhills/ike-scan
  *
  * Author: Roy Hills
  * Date: 5 April 2004
@@ -43,9 +42,6 @@
 
 #include "ike-scan.h"
 
-static char rcsid[] = "$Id$";	/* RCS ID for ident(1) */
-
-
 /*
  *	timeval_diff -- Calculates the difference between two timevals
  *	and returns this difference in a third timeval.
@@ -79,7 +75,7 @@ timeval_diff(const struct timeval *a, const struct timeval *b,
      temp.tv_usec += 1000000 * nsec;
      temp.tv_sec -= nsec;
    }
- 
+
    /* Compute the time difference
       tv_usec is certainly positive. */
    diff->tv_sec = a->tv_sec - temp.tv_sec;
@@ -105,7 +101,8 @@ struct timeval diff;
 unsigned diff_ms;
 
    timeval_diff(t1, t2, &diff);	/* diff = t1 - t2 */
-   diff_ms = abs(1000*diff.tv_sec + diff.tv_usec/1000);
+   /* Use labs() rather than abs() because time_t is normally "long" */
+   diff_ms = labs(1000*diff.tv_sec + diff.tv_usec/1000);
    if (diff_ms <= fuzz) {
       return 1;
    } else {
@@ -276,7 +273,7 @@ hex_or_num(const char *string, size_t *data_len) {
       value_be = htonl(value);
       data = Malloc(len);
       memcpy(data, &value_be, len);
-      
+
       *data_len = len;
       return data;
    }
@@ -780,7 +777,7 @@ str_ccmp( const char *s1, const char *s2 ) {
       if( c1 < c2            )  return  -1;
       if( c1 == 0 && c2 == 0 )  return   0;
    }
-} 
+}
 
 /*
  *	name_or_number -- Calculate the numeric value of a string containing
@@ -922,7 +919,3 @@ dupstr(const char *str) {
    strlcpy(cp, str, len);
    return cp;
 }
-
-void utils_use_rcsid(void) {
-   fprintf(stderr, "%s\n", rcsid);	/* Use rcsid to stop compiler optimising away */
-}
